
Lines
=====


.. automodule:: opendssdirect.Lines
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Lines.AllNames

    Get the name of all Line Objects.

.. function:: opendssdirect.Lines.Bus1

    Get the name of bus for terminal 1.Set the name of bus for terminal 1.

.. function:: opendssdirect.Lines.Bus2

    Get the name of bus for terminal 2.Set the name of bus for terminal 2.

.. function:: opendssdirect.Lines.C0

    Get the zero sequence capacitance, nanofarads per unit length.Set the zero sequence capacitance, nanofarads per unit length.

.. function:: opendssdirect.Lines.C1

    Get the positive sequence capacitance, nanofarads per unit length.Set the positive sequence capacitance, nanofarads per unit length.

.. function:: opendssdirect.Lines.CMatrix

    Get the capacitance matrix (full), nanofarads per unit length. Variant array of doubles.

.. function:: opendssdirect.Lines.Count

    Get the number of Line Objects in Active Circuit.

.. function:: opendssdirect.Lines.EmergAmps

    Get the emergency (maximum) ampere rating of Line.Set the emergency (maximum) ampere rating of Line.

.. function:: opendssdirect.Lines.First

    Set the first element active. Returns 0 if no Lines. Otherwise, index of the line element.

.. function:: opendssdirect.Lines.Geometry

    Get the name of the Line geometry code.Set the name of the Line geometry code.

.. function:: opendssdirect.Lines.Length

    Get the length of line section in units compatible with the LineCode definition.Set the length of line section in units compatible with the LineCode definition.

.. function:: opendssdirect.Lines.LineCode

    Get the name of LineCode object that defines the impedances.Set the name of LineCode object that defines the impedances.

.. function:: opendssdirect.Lines.Name

    Get the name of the active Line element.Set the name of the Line element to set it active.

.. function:: opendssdirect.Lines.Next

    Set the next element active. Returns 0 if no Lines. Otherwise, index of the line element.

.. function:: opendssdirect.Lines.NormAmps

    Get the normal ampere rating of Line.Set the normal ampere rating of Line.

.. function:: opendssdirect.Lines.NumCust

    Get the number of customers on this line section.

.. function:: opendssdirect.Lines.Parent

    Get the parents of the active Line to be the active Line. Return 0 if no parent or action fails.

.. function:: opendssdirect.Lines.Phases

    Get the number of phases of the active line object.Set the number of phases of the active line object.

.. function:: opendssdirect.Lines.R0

    Get the zero sequence resistance, ohm per unit length.Set the zero sequence resistance, ohm per unit length.

.. function:: opendssdirect.Lines.R1

    Get the positive sequence resistance, ohm per unit length.Set the positive sequence resistance, ohm per unit length.

.. function:: opendssdirect.Lines.RMatrix

    Get the resistance matrix (full), ohms per unit length. Variant array of doubles.

.. function:: opendssdirect.Lines.Rg

    Get the earth return value used to compute line impedances at power frequency.Set the earth return value used to compute line impedances at power frequency.

.. function:: opendssdirect.Lines.Rho

    Get the earth resistivity, m-ohms.Set the earth resistivity, m-ohms.

.. function:: opendssdirect.Lines.Spacing

    Get the name of the Line spacing code.Set the name of the Line spacing code.

.. function:: opendssdirect.Lines.Units

    Get the units of the line (distance, check manual for details).Set the units of the line (distance, check manual for details).

.. function:: opendssdirect.Lines.X0

    Get the zero sequence reactance, ohm per unit length.Set the zero sequence reactance, ohm per unit length.

.. function:: opendssdirect.Lines.X1

    Get the positive sequence reactance, ohm per unit length.Set the positive sequence reactance, ohm per unit length.

.. function:: opendssdirect.Lines.XMatrix

    Get the reactance matrix (full), ohms per unit length. Variant array of doubles.

.. function:: opendssdirect.Lines.Xg

    Get the earth return reactance value used to compute line impedances at power frequency.Set the earth return reactance value used to compute line impedances at power frequency.

.. function:: opendssdirect.Lines.Yprim

    Get the YPrimitive of the active Line.

